import React, { Component, Fragment } from "react";
import Loader from "~/components/Loader/index";
import Footer from "../Home/Footer/index";
import Navbar from "../Home/Navbar/index";
import BreadCrumb from "./BreadCrumb/index";
import VideoBox from "../QR/VideoBox/index";
import VoiceBox from "../QR/VoiceBox/index";

import { connect } from "react-redux";
import { publicApi } from "~/Redux/actions";

import "./index.scss";

const maxDesktopSize = 1250;

class Blog extends Component {
  getId() {
    return window.location.pathname.split("/").slice(-1)[0];
  }
  componentDidMount() {
    let id = this.getId();
    window.scrollTo(0, 0);
    this.props.getBlogInfo({
      [isNaN(+id) ? "name" : "id"]: id,
    });
  }

  render() {
    const fontSize = {
      desktop: {
        sidebar: {
          h1: window.innerWidth > maxDesktopSize ? 14 : window.innerWidth / 95,
          h2: window.innerWidth > maxDesktopSize ? 12 : window.innerWidth / 120,
          div:
            window.innerWidth > maxDesktopSize ? 12 : window.innerWidth / 120,
        },
        content: {
          h1: window.innerWidth > maxDesktopSize ? 18 : window.innerWidth / 75,
          p: window.innerWidth > maxDesktopSize ? 14 : window.innerWidth / 90,
          h2: window.innerWidth > maxDesktopSize ? 14 : window.innerWidth / 90,
        },
      },
    };
    const { blog } = this.props;
    return (
      <>
        {window.innerWidth > 1000 ? (
          <>
            {blog ? (
              <div className="landscape-blog d-flex flex-column">
                <Navbar />
                <div className="landscape-blog__header d-flex flex-column">
                  <BreadCrumb name={blog.title} />
                  <div className="landscape-blog__header--top d-flex">
                    <h1>{blog.title}</h1>
                  </div>
                  <div className="landscape-blog__header--bottom d-flex">
                    <div>{blog.date}</div>
                  </div>
                </div>
                <div className="landscape-blog__body d-flex flex-column">
                  <div className="landscape-blog__body--image d-flex">
                    <Identifier data={blog} fontSize={fontSize} />
                  </div>
                  <p className="landscape-blog__body--text d-flex">
                    <div dangerouslySetInnerHTML={{ __html: blog.text }}></div>
                  </p>
                </div>
              </div>
            ) : (
              <div
                className="d-flex justify-content-center align-items-center"
                style={{ height: "100vh", width: "100vw" }}
              >
                <Loader />
              </div>
            )}

            <Footer />
          </>
        ) : null}
        {window.innerWidth < 1000 ? (
          blog ? (
            <div className="portrait-blog d-flex flex-column">
              <Navbar />
              <div className="portrait-blog__header d-flex flex-column">
                <BreadCrumb name={blog.title} />
                <div className="portrait-blog__header--top d-flex">
                  <h1>{blog.title}</h1>
                </div>
                <div className="portrait-blog__header--bottom d-flex">
                  <h2>{blog.subTitle}</h2>
                  <div>{blog.date}</div>
                </div>
              </div>
              <div className="portrait-blog__body d-flex flex-column">
                <div className="portrait-blog__body--image d-flex">
                  <Identifier data={blog} />
                </div>
                <p
                  className="portrait-blog__body--text "
                  style={{ padding: 10, maxWidth: "95% !important" }}
                >
                  <div dangerouslySetInnerHTML={{ __html: blog.text }}></div>
                </p>
              </div>
            </div>
          ) : (
            <div
              className="d-flex justify-content-center align-items-center"
              style={{ height: "100vh", width: "100vw" }}
            >
              <Loader />
            </div>
          )
        ) : null}
      </>
    );
  }
}

export default connect(
  (state) => ({
    blog: state.publicApi.blog,
  }),
  { getBlogInfo: publicApi.getBlogInfo }
)(Blog);

const Identifier = (props) => {
  const { data } = props;
  return (
    <>
      {data.type === "audio" ? (
        <VoiceBox fontSize={props.fontSize} data={data} />
      ) : null}
      {data.type === "video" ? (
        <VideoBox fontSize={props.fontSize} data={data} />
      ) : null}
      {data.type === "image" ? (
        <img
          style={{ margin: "auto" }}
          src={"https://dnvn.ir/api/v1/file/" + data.fileIds}
          alt={data.fileIds}
        />
      ) : null}
    </>
  );
};
