import React, { Component } from "react";
import { Link } from "react-router-dom";
import { connect } from "react-redux";
import { publicApi } from "~/Redux/actions";

import Navbar from "../Home/Navbar";
import Footer from "../Home/Footer";
import BreadCrumb from "./BreadCrumb/index";
import Loader from "~/components/Loader/index";

import music from "~/assets/images/music.jpg";
import video from "~/assets/images/film.jpg";

import "./index.scss";

class Blogs extends Component {
  componentDidMount() {
    window.scrollTo(0, 0);
    this.props.getBlogList();
  }
  render() {
    const { list } = this.props;
    return (
      <>
        {window.innerWidth > 1000 ? (
          <>
            {list.length > 0 ? (
              <div className="landscape-blogs d-flex flex-column">
                <Navbar />
                <BreadCrumb />
                <div className="landscape-blogs__scroll d-flex flex-column">
                  {list.map((item) => (
                    <Item item={item} key={item.id} />
                  ))}
                </div>
              </div>
            ) : (
              <div
                className="d-flex justify-content-center align-items-center"
                style={{ height: "100vh", width: "100vw" }}
              >
                <Loader />
              </div>
            )}

            <Footer />
          </>
        ) : null}
        {window.innerWidth < 1000 ? (
          <div className="portrait-blogs d-flex flex-column">
            {list.length > 0 ? (
              <>
                <Navbar />
                <BreadCrumb />
                <div className="portrait-blogs__scroll d-flex flex-column">
                  {list.map((item) => (
                    <Item item={item} key={item.id} />
                  ))}
                </div>
              </>
            ) : (
              <div
                className="d-flex justify-content-center align-items-center"
                style={{ height: "100vh", width: "100vw" }}
              >
                <Loader />
              </div>
            )}
          </div>
        ) : null}
      </>
    );
  }
}

const Item = (props) => {
  const { item } = props;
  return (
    <>
      {window.innerWidth > 1000 ? (
        <Link to={"/blogs/" + item.id} className="landscape-blogs-item d-flex">
          <div className="landscape-blogs-item__pic">
            {item.type === "image" ? (
              <img
                src={`https://dnvn.ir/api/v1/file/${item.fileIds}`}
                alt={item.title}
              />
            ) : null}
            {item.type === "video" ? (
              <img src={video} alt={item.title} />
            ) : null}
            {item.type === "audio" ? (
              <img src={music} alt={item.title} />
            ) : null}
          </div>
          <div className="landscape-blogs-item__left d-flex flex-column">
            <h1>{item.title}</h1>
            <span>مطالعه کامل</span>
          </div>
        </Link>
      ) : null}
      {window.innerWidth < 1000 ? (
        <Link
          to={"/blogs/" + item.id}
          className="portrait-blogs-item d-flex flex-column"
        >
          {item.type === "image" ? (
            <img
              src={`https://dnvn.ir/api/v1/file/${item.fileIds}`}
              alt={item.title}
            />
          ) : null}
          {item.type === "video" ? <img src={video} alt={item.title} /> : null}
          {item.type === "audio" ? <img src={music} alt={item.title} /> : null}
          <h1>{item.title}</h1>
          {/* <p>{item.text}</p> */}
          <span>مطالعه کامل</span>
        </Link>
      ) : null}
    </>
  );
};

export default connect(
  (state) => ({
    list: state.publicApi.blogList,
  }),
  { getBlogList: publicApi.getBlogList }
)(Blogs);
