import React, { Component } from "react";
import { SortableContainer, SortableElement } from "react-sortable-hoc";
import arrayMove from "array-move";
import ArrowRightAltIcon from "@material-ui/icons/ArrowRightAlt";

export default class DraggableMessage extends Component {
  constructor(props) {
    super(props);
    this.state = this.props.message;
  }
  onSortEnd = ({ oldIndex, newIndex }) => {
    if (this.props.isActive)
      this.setState(({ options }) => ({
        options: arrayMove(options, oldIndex, newIndex),
      }));
  };

  render() {
    const { isActive, action } = this.props;

    return (
      <div className="message-2d d-flex flex-column d-flex">
        <SortableList
          items={this.state.options}
          onSortEnd={this.onSortEnd}
          disabled={!isActive}
        />
        {isActive && (
          <button className="message-2d__submit" onClick={() => action()}>
            ثبت
            <ArrowRightAltIcon />
          </button>
        )}
      </div>
    );
  }
}

const SortableList = SortableContainer(({ items, disabled }) => {
  return (
    <div className="message-2d__options d-flex flex-column">
      {items.map((row, index) => (
        <SortableItem
          key={`item-${index}`}
          index={index}
          value={row}
          disabled={disabled}
        />
      ))}
    </div>
  );
});

const SortableItem = SortableElement(({ value }) => (
  <div className="message-2d__options--row d-flex">
    {value.map((item) => (
      <div>{item.name}</div>
    ))}
  </div>
));
