import React, { Component } from "react";
import { connect } from "react-redux";
import { publicApi } from "~/Redux/actions";

import Navbar from "../Home/Navbar/index";
import Footer from "../Home/Footer/index";

import location from "../../assets/icons/location.png";
import home from "../../assets/icons/home.png";
import contact from "../../assets/icons/contact.png";
import Location from "./Location/Location";
import Loader from "~/components/Loader/index";
import Support from "../Support";
import "./index.scss";

const maxDesktopSize = 1250;
const maxMobileSize = 550;

const fontSize = {
  desktop: {
    h1: window.innerWidth > maxDesktopSize ? 30 : window.innerWidth / 40,
    p: window.innerWidth > maxDesktopSize ? 14 : window.innerWidth / 80,
    span: window.innerWidth > maxDesktopSize ? 16 : window.innerWidth / 80,
  },
  mobile: {
    h1: window.innerWidth > maxMobileSize ? 25 : window.innerWidth / 16,
    p: window.innerWidth > maxMobileSize ? 14 : window.innerWidth / 34,
    span: window.innerWidth > maxMobileSize ? 15 : window.innerWidth / 32,
  },
};

class Contact extends Component {
  state = {
    name: null,
    cellphone: null,
    unit: null,
    book: null,
    subject: null,
    text: null,
  };

  componentDidMount() {
    if (!this.props.contactData?.address) this.props.getContactData();
  }

  render() {
    const { contactData, loading } = this.props;
    return (
      <>
        {window.innerWidth > 1000 ? (
          !loading ? (
            <>
              <div className="contact d-flex flex-column align-items-center">
                <Navbar page={"contact"} />
                <div className="contact__forms d-flex">
                  <div className="contact__forms--right d-flex flex-column">
                    <Support />
                  </div>
                  <div className="contact__forms--left d-flex flex-column">
                    <div className="contact__location d-flex align-items-center">
                      <img src={location} alt="آدرس" className="m-1" />
                      <p style={{ fontSize: fontSize.desktop.p }}>
                        {contactData?.address || ""}
                      </p>
                    </div>
                    <div
                      className="d-flex align-items-center mt-1"
                      style={{ width: "55%", justifyContent: "space-between" }}
                    >
                      <div className="d-flex align-items-center">
                        <span style={{ fontSize: fontSize.desktop.span }}>
                          {contactData?.cellphone || ""}
                        </span>
                        <img src={contact} alt="تماس" className="m-1" />
                      </div>
                      <div className="d-flex align-items-center">
                        <span style={{ fontSize: fontSize.desktop.span }}>
                          {contactData?.email || ""}
                        </span>
                        <img src={home} alt="خانه" className="m-1" />
                      </div>
                    </div>
                    <div className="contact__map d-flex align-items-center mt-3">
                      <Location />
                    </div>
                  </div>
                </div>
              </div>
              <Footer />
            </>
          ) : (
            <div
              className="d-flex justify-content-center align-items-center"
              style={{ height: "100vh", width: "100vw" }}
            >
              <Navbar page={"contact"} />
              <Loader />
            </div>
          )
        ) : null}
        {window.innerWidth < 1000 ? (
          !loading ? (
            <div className="mobile-contact d-flex flex-column align-items-center">
              <Navbar page={"contact"} />

              <Support />
              <div className="mobile-contact__address d-flex flex-column">
                <div className="mobile-contact__address--location d-flex align-items-center">
                  <img src={location} alt="آدرس" className="m-1" />
                  <p style={{ fontSize: fontSize.mobile.p }}>
                    {contactData?.address || ""}{" "}
                  </p>
                </div>
                <div
                  className="d-flex align-items-center mt-1"
                  style={{ width: "55%", justifyContent: "space-between" }}
                >
                  <div className="d-flex align-items-center">
                    <span style={{ fontSize: fontSize.mobile.span }}>
                      {contactData?.cellphone || ""}{" "}
                    </span>
                    <img src={contact} alt="تماس" className="m-1" />
                  </div>
                  <div className="d-flex align-items-center">
                    <span style={{ fontSize: fontSize.mobile.span }}>
                      {contactData?.email || ""}
                    </span>
                    <img src={home} alt="خانه" className="m-1" />
                  </div>
                </div>
                <div className="mobile-contact__address--map d-flex align-items-center mt-3">
                  <Location />
                </div>
              </div>
            </div>
          ) : (
            <div
              className="d-flex justify-content-center align-items-center"
              style={{ height: "100vh", width: "100vw" }}
            >
              <Navbar page={"contact"} />
              <Loader />
            </div>
          )
        ) : null}
      </>
    );
  }
}

export default connect(
  (state) => ({
    loading: state.publicApi.loading,
    contactData: state.publicApi.contactData,
    list: state.userProduct.mylist || [],
    //loading: state.publicApi.loading,
  }),
  { getContactData: publicApi.getContactData }
)(Contact);
