import React, { Component } from "react";
import { connect } from "react-redux";
import { publicApi } from "~/Redux/actions";

import KeyboardArrowUpIcon from "@material-ui/icons/KeyboardArrowUp";
import KeyboardArrowDownIcon from "@material-ui/icons/KeyboardArrowDown";

import "./index.scss";

const maxDesktopSize = 1250;
const maxMobileSize = 550;

const fontSize = {
  mobile: {
    h2: window.innerWidth > maxMobileSize ? 18 : window.innerWidth / 28,
    div: window.innerWidth > maxDesktopSize ? 14 : window.innerWidth / 34,
  },
  desktop: {
    h2: window.innerWidth > maxMobileSize ? 16 : window.innerWidth / 85,
    div: window.innerWidth > maxDesktopSize ? 14 : window.innerWidth / 95,
  },
};

class Collapse extends Component {
  render() {
    const { message, setFaqActive } = this.props;
    return (
      <div className="collapse d-flex flex-column">
        <div
          className={`collapse__header d-flex ${
            message.active ? "collapse-header-border" : null
          }`}
          style={{
            borderColor: message.active ? "#7dc241" : "rgb(223, 223, 223)",
            borderBottom: message.active ? 0 : "1px solid rgb(223, 223, 223)",
          }}
          onClick={() => setFaqActive(message.id)}
        >
          <h2
            style={{
              color: message.active ? "#7dc241" : "#666",
              fontSize:
                window.innerWidth > 1000
                  ? fontSize.desktop.h2
                  : fontSize.mobile.h2,
            }}
          >
            {message.title}
          </h2>
          {message.active ? (
            <KeyboardArrowUpIcon
              style={{
                fontSize: 30,
                color: message.active ? "#7dc241" : "grey",
              }}
            />
          ) : (
            <KeyboardArrowDownIcon
              style={{
                fontSize: 30,
                color: message.active ? "#7dc241" : "grey",
              }}
            />
          )}
        </div>
        {message.active ? (
          <div
            className="collapse__body"
            style={{
              borderColor: message.active ? "#7dc241" : "rgb(223, 223, 223)",
              borderTop: 0,
              fontSize:
                window.innerWidth > 1000
                  ? fontSize.desktop.div
                  : fontSize.mobile.div,
            }}
          >
            {message.description}
          </div>
        ) : null}
      </div>
    );
  }
}

export default connect(() => ({}), {
  setFaqActive: publicApi.setFaqActive,
})(Collapse);
