import React from "react";
import { connect } from "react-redux";
import { userProduct } from "~/Redux/actions";
import { Link } from "react-router-dom";

import Navbar from "../Home/Navbar/index";
import Footer from "../Home/Footer/index";
import BreadCrumbs from "./BreadCrumb/index";
import Loader from "~/components/Loader/index";

import "./index.scss";
const maxDesktopSize = 1250;
const maxMobileSize = 550;

const fontSize = {
  mobile: {
    h1: window.innerWidth > maxMobileSize ? 24 : window.innerWidth / 20,
    a: window.innerWidth > maxMobileSize ? 15 : window.innerWidth / 30,
    p: window.innerWidth > maxMobileSize ? 14 : window.innerWidth / 30,
  },
  desktop: {
    h1: window.innerWidth > maxDesktopSize ? 18 : window.innerWidth / 70,
    a: window.innerHeight > maxDesktopSize ? 15 : window.innerWidth / 85,
    p: window.innerWidth > maxDesktopSize ? 14 : window.innerWidth / 90,
  },
};

class MyBooks extends React.Component {
  componentDidMount() {
    window.scrollTo(0, 0);
  }

  render() {
    const { list, checkEmpty, loading } = this.props;
    return (
      <>
        {window.innerWidth > 1000 ? (
          !loading ? (
            <>
              <div className="mybooks d-flex flex-column">
                <Navbar />
                <BreadCrumbs />
                <div className="mybooks__list d-flex flex-wrap p-1">
                  {!checkEmpty ? (
                    list.map((item, i) => <Item data={item} key={i} id={i} />)
                  ) : (
                    <div
                      className="mybooks__list--empty d-flex flex-column justify-content-center align-items-center"
                      style={{ width: "100vw", height: "calc(100vh - 400px)" }}
                    >
                      <p style={{ fontSize: fontSize.desktop.p }}>
                        برای استفاده از این بخش باید یک کتاب فعال خریداری کرده
                        باشید
                      </p>
                      <Link to="/products">فروشگاه</Link>
                    </div>
                  )}
                </div>
              </div>
              <Footer />
            </>
          ) : (
            <div
              className="d-flex justify-content-center align-items-center"
              style={{ height: "100vh", width: "100vw" }}
            >
              <Loader />
            </div>
          )
        ) : null}
        {window.innerWidth < 1000 ? (
          !loading ? (
            <>
              <div className="mobile-products d-flex flex-column">
                <Navbar />

                <div className="d-flex flex-wrap p-1">
                  {!checkEmpty ? (
                    list.map((item, i) => <Item data={item} key={i} id={i} />)
                  ) : (
                    <div
                      className="mobile-products__empty d-flex flex-column justify-content-center align-items-center text-center"
                      style={{ height: "calc(100vh - 100px)", width: "100vw" }}
                    >
                      <p style={{ fontSize: fontSize.mobile.p }}>
                        برای استفاده از این بخش باید یک کتاب فعال خریداری کرده
                        باشید
                      </p>
                      <Link to="/products">فروشگاه</Link>
                    </div>
                  )}
                </div>
              </div>
            </>
          ) : (
            <div
              className="d-flex justify-content-center align-items-center"
              style={{ height: "100vh", width: "100vw" }}
            >
              <Loader />
            </div>
          )
        ) : null}
      </>
    );
  }
}

export default connect(
  (state) => ({
    list: state.userProduct.mylist || [],
    checkEmpty: state.userProduct.checkEmpty,
    // status: state.user.status,
  }),
  { getList: userProduct.mylist }
)(MyBooks);

const Item = (props) => {
  const { data } = props;
  return (
    <>
      {window.innerWidth < 1000 &&
      data.condition === 2 &&
      data.product.productType === (1 || 3) ? (
        <div className="mobile-products-product d-flex flex-column">
          <img
            src={`https://dnvn.ir/api/v1/file/${data.product.book.fileIds}`}
            alt={"عکس مجصول"}
          />
          <div className="mobile-products-product__info d-flex flex-column">
            <h1 style={{ fontSize: fontSize.mobile.h1 }}>
              {data.product.book.name}
            </h1>
          </div>
        </div>
      ) : null}
      {window.innerWidth > 1000 &&
      data.condition === 2 &&
      data.product.productType === (1 || 3) ? (
        <div className="products-product d-flex flex-column">
          <img
            src={`https://dnvn.ir/api/v1/file/${data.product.book.fileIds}`}
            alt={"عکس مجصول"}
          />
          <div className="mobile-products-product__info d-flex flex-column">
            <h1 style={{ fontSize: fontSize.desktop.h1 }}>
              {data.product.book.name}
            </h1>
          </div>
        </div>
      ) : null}
    </>
  );
};
