import React from "react";

import MaterialAudioPlayer from "../VoiceBox/Material-audio-player/index";

import "./index.scss";

const maxDesktopSize = 1250;

const fontSize = {
  desktop: {
    h2: window.innerWidth > maxDesktopSize ? 14 : window.innerWidth / 120,
    ppt: {
      h2: window.innerWidth > maxDesktopSize ? 12 : window.innerWidth / 120,
    },
    voice: {
      h2: window.innerWidth > maxDesktopSize ? 12 : window.innerWidth / 120,
    },
    links: {
      li: window.innerWidth > maxDesktopSize ? 13 : window.innerWidth / 110,
    },
  },
};

export default function BookContent(props) {
  return (
    <div className="book-content d-flex flex-column mt-4">
      <header className="book-content__header d-flex align-items-center">
        <h2 style={{ fontSize: fontSize.desktop.h2 }}>محتویات کتاب</h2>
        <span></span>
      </header>
      {props.data.map((item, i) => (
        <Identifier data={item} key={i} />
      ))}
    </div>
  );
}

const Identifier = (props) => {
  return (
    <>
      {props.data.type === "voice" ? (
        <a href="#voice" className="book-content-voice d-flex flex-column">
          <h2
            style={{ fontSize: fontSize.desktop.voice.h2 }}
            className="d-flex align-items-center"
          >
            <span></span>
            {props.data.name}
          </h2>
          <MaterialAudioPlayer />
        </a>
      ) : null}
      {props.data.type === "video" ? (
        <a href="#video" className="book-content-video d-flex">
          <h2
            style={{ fontSize: fontSize.desktop.ppt.h2 }}
            className="d-flex align-items-center"
          >
            <span></span>
            {props.data.name}
          </h2>
        </a>
      ) : null}
      {props.data.type === "pdf" ? (
        <a href="#pdf" className="book-content-pdf d-flex">
          <h2
            style={{ fontSize: fontSize.desktop.ppt.h2 }}
            className="d-flex align-items-center"
          >
            <span></span>
            {props.data.name}
          </h2>
        </a>
      ) : null}
      {props.data.type === "ppt" ? (
        <a href="#ppt" className="book-content-ppt d-flex">
          <h2
            style={{ fontSize: fontSize.desktop.ppt.h2 }}
            className="d-flex align-items-center"
          >
            <span></span>
            {props.data.name}
          </h2>
        </a>
      ) : null}
      {props.data.type === "links" ? (
        <div className="book-content-links d-flex flex-column">
          <ul>
            {props.data.links.map((item, i) => (
              <Item data={item} key={i} />
            ))}
          </ul>
        </div>
      ) : null}
    </>
  );
};

const Item = (props) => {
  return (
    <li style={{ fontSize: fontSize.desktop.links.li }}>
      <a href={props.data.link}>{props.data.name}</a>
    </li>
  );
};
