import React, { useState } from "react";
import KeyboardArrowUpIcon from "@material-ui/icons/KeyboardArrowUp";
import KeyboardArrowDownIcon from "@material-ui/icons/KeyboardArrowDown";
import navbarSearch from "../../../assets/icons/navbarSearch.png";
import "./index.scss";

const maxDesktopSize = 1250;

const fontSize = {
  desktop: {
    h3: window.innerWidth > maxDesktopSize ? 12 : window.innerWidth / 120,
    input: window.innerWidth > maxDesktopSize ? 14 : window.innerWidth / 110,
    li: window.innerWidth > maxDesktopSize ? 12 : window.innerWidth / 120,
  },
};

export default function Dropdown(props) {
  const [dropdown, setDropdown] = useState(false);
  const [searchedSubjects, setSearchedSubjects] = useState(null);
  const [search, setSearch] = useState("");

  const handleSearch = (val) => {
    let fakeList = props.subjects.filter(
      (item) => item.name.search(val) !== -1
    );
    setSearchedSubjects(fakeList);
    setSearch(val);
  };
  return (
    <div className="subjects-dropdown d-flex flex-column mt-3">
      <div
        className="d-flex align-items-center justify-content-between"
        onClick={() => setDropdown(!dropdown)}
      >
        <h3 style={{ fontSize: fontSize.desktop.h3 }}>
          مشاهده فهرست موضوعی کتاب
        </h3>
        <div>
          {dropdown ? (
            <KeyboardArrowUpIcon
              style={{ color: "#afafaf", fontSize: 30, cursor: "pointer" }}
            />
          ) : (
            <KeyboardArrowDownIcon
              style={{ color: "#afafaf", fontSize: 30, cursor: "pointer" }}
            />
          )}
        </div>
      </div>
      {dropdown ? (
        <>
          <div className="subjects-dropdown__search d-flex">
            <input
              type="search"
              style={{ fontSize: fontSize.desktop.input }}
              onChange={(e) => handleSearch(e.target.value)}
            />
            <img src={navbarSearch} alt="جستجو" />
          </div>
          <ul>
            {search
              ? searchedSubjects.map((item, i) => <Item data={item} key={i} />)
              : props.subjects.map((item, i) => <Item data={item} key={i} />)}
          </ul>
        </>
      ) : null}
    </div>
  );
}

Dropdown.defaultProps = {
  subjects: [
    { id: 0, name: "مقدمه" },
    { id: 1, name: "سخنی با خوانندگان" },
    { id: 2, name: "آتشفشانها و اقیانوسها" },
    { id: 3, name: "نحوه جدایی صفحات کره" },
  ],
};

const Item = (props) => {
  return <li style={{ fontSize: fontSize.desktop.li }}>{props.data.name}</li>;
};
